# Generated by ariadne-codegen
# Source: operations.graphql

from typing import List

from stigg._vendors.pydantic import Field

from .base_model import BaseModel
from .fragments import CreditLedgerFragment


class GetCreditLedger(BaseModel):
    credits_ledger: "GetCreditLedgerCreditsLedger" = Field(alias="creditsLedger")


class GetCreditLedgerCreditsLedger(BaseModel):
    events: List["GetCreditLedgerCreditsLedgerEvents"]


class GetCreditLedgerCreditsLedgerEvents(CreditLedgerFragment):
    pass


GetCreditLedger.model_rebuild()
GetCreditLedgerCreditsLedger.model_rebuild()
